<?php

namespace Litecrm\Call\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecrm\Call\Models\Dbupload;

class DbuploadPolicy
{

    /**
     * Determine if the given user can view the dbupload.
     *
     * @param UserPolicy $user
     * @param Dbupload $dbupload
     *
     * @return bool
     */
    public function view(UserPolicy $user, Dbupload $dbupload)
    {
        if ($user->canDo('call.dbupload.view') && $user->isAdmin()) {
            return true;
        }

        return $dbupload->user_id == user_id() && $dbupload->user_type == user_type();
    }

    /**
     * Determine if the given user can create a dbupload.
     *
     * @param UserPolicy $user
     * @param Dbupload $dbupload
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('call.dbupload.create');
    }

    /**
     * Determine if the given user can update the given dbupload.
     *
     * @param UserPolicy $user
     * @param Dbupload $dbupload
     *
     * @return bool
     */
    public function update(UserPolicy $user, Dbupload $dbupload)
    {
        if ($user->canDo('call.dbupload.edit') && $user->isAdmin()) {
            return true;
        }

        return $dbupload->user_id == user_id() && $dbupload->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given dbupload.
     *
     * @param UserPolicy $user
     * @param Dbupload $dbupload
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Dbupload $dbupload)
    {
        return $dbupload->user_id == user_id() && $dbupload->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given dbupload.
     *
     * @param UserPolicy $user
     * @param Dbupload $dbupload
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Dbupload $dbupload)
    {
        if ($user->canDo('call.dbupload.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given dbupload.
     *
     * @param UserPolicy $user
     * @param Dbupload $dbupload
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Dbupload $dbupload)
    {
        if ($user->canDo('call.dbupload.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
